==> mule-metadata-extension-4.5.0-20220622-sources.jar: org/mule/test/metadata/extension/resolver/SdkTestOutputAttributesResolverWithKeyResolver.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.metadata.extension.resolver;

import static org.mule.metadata.api.model.MetadataFormat.JAVA;

import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.ObjectTypeBuilder;
import org.mule.metadata.api.model.MetadataType;
import org.mule.runtime.api.connection.ConnectionException;
import org.mule.runtime.api.metadata.MetadataKey;
import org.mule.runtime.api.metadata.MetadataResolvingException;
import org.mule.runtime.api.metadata.resolving.TypeKeysResolver;
import org.mule.sdk.api.metadata.MetadataContext;
import org.mule.sdk.api.metadata.resolving.AttributesTypeResolver;
import org.mule.sdk.api.metadata.resolving.OutputTypeResolver;

import java.util.Set;

public class SdkTestOutputAttributesResolverWithKeyResolver
    implements TypeKeysResolver, OutputTypeResolver<String>, AttributesTypeResolver<String> {

  @Override
  public Set<MetadataKey> getKeys(org.mule.runtime.api.metadata.MetadataContext context)
      throws MetadataResolvingException, ConnectionException {
    return TestMetadataResolverUtils.getKeys(context);
  }

  @Override
  public MetadataType getOutputType(MetadataContext context, String key) throws MetadataResolvingException {
    return TestMetadataResolverUtils.getMetadata(key);
  }

  @Override
  public MetadataType getAttributesType(MetadataContext context, String key)
      throws MetadataResolvingException, ConnectionException {
    ObjectTypeBuilder builder = BaseTypeBuilder.create(JAVA).objectType();
    builder.openWith().stringType();
    return builder.build();
  }

  @Override
  public String getCategoryName() {
    return "MetadataExtensionResolver";
  }

  @Override
  public String getResolverName() {
    return "TestOutputAttributesResolverWithKeyResolver";
  }
}

==> mule-metadata-extension-4.5.0-20221117-sources.jar: org/mule/test/metadata/extension/resolver/SdkTestOutputAttributesResolverWithKeyResolver.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.metadata.extension.resolver;

import static org.mule.metadata.api.model.MetadataFormat.JAVA;

import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.ObjectTypeBuilder;
import org.mule.metadata.api.model.MetadataType;
import org.mule.runtime.api.connection.ConnectionException;
import org.mule.runtime.api.metadata.MetadataKey;
import org.mule.runtime.api.metadata.MetadataResolvingException;
import org.mule.runtime.api.metadata.resolving.TypeKeysResolver;
import org.mule.sdk.api.metadata.MetadataContext;
import org.mule.sdk.api.metadata.resolving.AttributesTypeResolver;
import org.mule.sdk.api.metadata.resolving.OutputTypeResolver;

import java.util.Set;

public class SdkTestOutputAttributesResolverWithKeyResolver
    implements TypeKeysResolver, OutputTypeResolver<String>, AttributesTypeResolver<String> {

  @Override
  public Set<MetadataKey> getKeys(org.mule.runtime.api.metadata.MetadataContext context)
      throws MetadataResolvingException, ConnectionException {
    return TestMetadataResolverUtils.getKeys(context);
  }

  @Override
  public MetadataType getOutputType(MetadataContext context, String key) throws MetadataResolvingException {
    return TestMetadataResolverUtils.getMetadata(key);
  }

  @Override
  public MetadataType getAttributesType(MetadataContext context, String key)
      throws MetadataResolvingException, ConnectionException {
    ObjectTypeBuilder builder = BaseTypeBuilder.create(JAVA).objectType();
    builder.openWith().stringType();
    return builder.build();
  }

  @Override
  public String getCategoryName() {
    return "MetadataExtensionResolver";
  }

  @Override
  public String getResolverName() {
    return "SdkTestOutputAttributesResolverWithKeyResolver";
  }
}
